Эхолот Humminbird 788cxi HD DI Combo / spinkat.ru

форум
+7(963)755-97-22
+7(978)100-77-06
e-mail: info@spinkat.ru
Войти/Зарегистрироваться

- Доставка по Москве
  и всей России
- Консультации
  экспертов

Корзина пока пуста
Блог
интересные записи
Погода
Посмотеть погоду
Главная Рыболовная электроника Рыбопоисковая техника Эхолот Humminbird 788cxi HD DI Combo

## Эхолот Humminbird 788cxi HD DI Combo

Заполните все поля и нажмите кнопку «Отправить».

Ваше имя: |
Ваш e-mail: |
Сообщение: |
обновить |

Дополнительные фото:

Рейтинг:
Отзывы (0)

Нет в наличии

0.00 руб. В корзину Отложить

- Wish List
- Обзоры
- Задать вопрос эксперту

Производитель:Humminbird США

###### Характеристики:

- Артикул: HB-788CXIHDDICOMBO

ОписаниеДополнительные товары(0)Отзывы(0)Видео (нет)Статьи(0)Обзоры(0)
Эхолот Humminbird 788ci HD DI Combo руссифицирован и имеет лучший в своем классе пятидюймовый экран высокого разрешения (640 х 640 пикс.) со светодиодной подсветкой, DualBeam PLUS сонар с 4000 Ватт мощности. GPS картплоттер имеет расширенные возможности для рыбалки. Кроме того Humminbird 788ci HD DI Combo имеет на корпусе два слота карт SD для подробных морских карт и сохранения путевых точек,видео и изображений с экрана эхолота,а также три программируемые кнопки предварительной настройки, чтобы сохранить ваши любимые виды. Максимизируйте рыбалку с профессиональным эхолотом Humminbird 788ci HD DI Combo.
Основные характеристики:
Диагональ экрана:5"
Количество лучей:2
GPS-модуль:Есть
Размер экрана (В х Ш), мм:12,7 (диагональ - 5")
Разрешение экрана (В x Ш), пикс.:640 х 640
Тип экрана:TFT
Цвета/уровни серого:256 цветов
Стандартный сонар:Down Imaging/SinglelBeam PLUS
Охват сонара:20˚,50˚ и 86°
Частота сонара, кГц:200/83/455
Дополнительный сонар:нет
Разделение целей, см:6,35
Мощность излучения, Вт:500 (средняя) / 4000 (пиковая)
Потребляемый ток, мА (без подсветки):615
Максимальная глубина, м:457
Температура:Да
Скорость:по GPS
Подсветка:Да
Водонепроницаемость:Да
Габариты (Ш х В х Г), мм:175 х 191 х 114
Крепление:Быстросъемное или в панель
Стандартный датчик:XNT-9-Di-T
Стандартное крепление датчика:Транец
Питание, В (постоянного тока):10-20
Для рыбалки с лодки (РЛ):Да
Возможности управления:
SwichFire Sonar*: да
*(управление сигналом, переключение режимов отображния данных. Режим CLEAR отображает только обнаруживаемые объкты и рыбу. Режим MAX обеспечивает высокую детализизацию изображения с помощью которого можно увидеть мельчайшие объекты - растительность, термоклин, рыбу и подводные течения)
Сохранение скриншота на карту памяти: да
Запись с сонара: да
Зум в отдельном окне: да
Слежение за дном в отдельном окне: да
Трехмерное изображение: да
Крупные цифры: да
Одновременный вывод узкого и широкого конуса: да
Настройка типа изображения: да
Настройка цифровой индикации: да
Выбор цветов экрана: да
Настройка кнопок изображения: да
Индикация температуры: да
Сигнал о температуре: да
Мнгновенное обновление изображения: да
отметки объектов на сонаре: да
Селективный Fish ID+: да
усилитель сонара: да
Комплект поставки:
Эхолот Humminbird 788сxi HD DI Combo (дисплей)
Защитная крышка на экран
Датчик основной XNT-9-Di-T (длина кабеля - 6 метров)
Крепёжное основание для дисплея эхолота
Крепление на саморезах для основного датчика на транец лодки
Кабель питания эхолота PC-10 (длина - 1.8 метра)
Держатель для кабелей эхолота
Подробная инструкция на русском языке
Инструкция по установке датчика на русском языке
Официальная гарантия - 2 года
Индекс "x" в названии означает официальную поставку и поддержку эхолота на территории Российкой Федерации.

Оставить отзыв

Заполните все поля и нажмите кнопку «Отправить».

Ваше имя: |
Ваш e-mail: |
Оценка: | 5 4 3 2
Отзыв: |
обновить |

## ???? ??? ????????

Email: |
??????: |

?????? ?????????????????????????

## ?????? ??????

???: |
Email: |
???????: |
??????: |
???????? |